==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Web_Links/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","Vorige pagina");
define("_NEXT","Volgende pagina");
define("_YOURNAME","Uw naam");
define("_CATEGORY","Categorie");
define("_CATEGORIES","Categorien");
define("_LVOTES","Stemmen");
define("_TOTALVOTES","Totaal aantal stemmen:");
define("_LINKTITLE","Linktitel");
define("_HITS","Hits:");
define("_THEREARE","Er zijn");
define("_NOMATCHES","Geen overeenkomsten gevonden");
define("_SCOMMENTS","Opmerkingen");
define("_DESCRIPTION","Beschrijving");
define("_ONLYREGUSERSMODIFY","Alleen leden kunnen suggesties doen m.b.t. downloadwijzigingen. A.u.b. <a href=\"modules.php?name=Your_Account\">registreren of inloggen</a>.");
define("_DATE","Datum");
define("_TO","Aan");
define("_ADDLINK","Link toevoegen");
define("_NEW","Nieuw");
define("_POPULAR","Populair");
define("_TOPRATED","Hoog(st) gewaardeerd");
define("_RANDOM","Willekeurig");
define("_LINKSMAIN","Hoofdlinks");
define("_LINKCOMMENTS","Link opmerkingen");
define("_ADDITIONALDET","Extra details");
define("_EDITORREVIEW","Auteurs recentie");
define("_REPORTBROKEN","Ongeldige link rapporteren");
define("_LINKSMAINCAT","Hoofdlinks categorien");
define("_AND","en");
define("_INDB","in onze database");
define("_ADDALINK","Nieuwe link toevoegen");
define("_INSTRUCTIONS","Instructies");
define("_SUBMITONCE","En link maar n keer inzenden.");
define("_POSTPENDING","Alle links worden geplaatst, in afwachting van goedkeuring.");
define("_USERANDIP","Gebruikersnaam en IP-adres worden geregistreerd, misbruik het systeem a.u.b. niet.");
define("_PAGETITLE","Paginatitel");
define("_PAGEURL","Pagina URL");
define("_YOUREMAIL","Uw e-mailadres");
define("_LDESCRIPTION","Beschrijving (max. 255 karakters):");
define("_ADDURL","Deze URL toevoegen");
define("_LINKSNOTUSER1","U bent geen geregistreerde gebruiker of U bent niet ingelogd.");
define("_LINKSNOTUSER2","Als U lid bent, kunt U links op deze website toevoegen.");
define("_LINKSNOTUSER3","Registreren duurt niet lang, en is niet moeilijk.");
define("_LINKSNOTUSER4","Waarom moet U zich registreren om toegang te krijgen tot bepaalde gedeeltes van deze site?");
define("_LINKSNOTUSER5","Alleen dan kunnen wij garant staan voor de inhoud van de inzendingen.");
define("_LINKSNOTUSER6","Elke inzending worden bekeken en daarna goed- of afgekeurd.");
define("_LINKSNOTUSER7","Wij streven ernaar u alleen nuttige informatie aan te bieden.");
define("_LINKSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Aanmelden voor een account</a>");
define("_LINKALREADYEXT","FOUT: Deze URL is reeds opgenomen in de database!");
define("_LINKNOTITLE","FOUT: U moet een TITEL opgeven voor uw URL!");
define("_LINKNOURL","FOUT: U moet een URL opgeven voor uw URL!");
define("_LINKNODESC","FOUT: U moet een BESCHRIJVING opgeven voor uw URL!");
define("_LINKRECEIVED","Wij hebben uw link-inzending ontvangen. Bedankt!");
define("_EMAILWHENADD","U zult een e-mail ontvangen als deze inzending goedgekeurd wordt.");
define("_CHECKFORIT","U heeft geen e-mailadres opgegeven. U zult daarom geen plaatsingsbericht ontvangen.");
define("_NEWLINKS","Nieuwe links");
define("_TOTALNEWLINKS","Totaal aantal nieuwe links");
define("_LASTWEEK","Laatste week");
define("_LAST30DAYS","Laatste 30 dagen");
define("_1WEEK","1 week");
define("_2WEEKS","2 weken");
define("_30DAYS","30 dagen");
define("_SHOW","Geef weer");
define("_TOTALFORLAST","Totaal aantal nieuwe links van de laatste");
define("_DAYS","dagen");
define("_ADDEDON","Toegevoegd op");
define("_RATING","Waardering");
define("_RATESITE","Waardering van deze site");
define("_DETAILS","Details");
define("_BESTRATED","Hoog gewaardeerde links - Top");
define("_OF","van");
define("_TRATEDLINKS","totaal aantal gewaardeerde links");
define("_TVOTESREQ","minimum aantal stemmen nodig");
define("_SHOWTOP","Geef Top weer");
define("_MOSTPOPULAR","Populairste links - Top");
define("_OFALL","van alle");
define("_SORTLINKSBY","Sorteer links op");
define("_SITESSORTED","Sites nu gesorteerd op");
define("_POPULARITY","Populariteit");
define("_SELECTPAGE","Selecteer pagina");
define("_MAIN","Hoofd");
define("_NEWTODAY","Nieuw vandaag");
define("_NEWLAST3DAYS","Nieuw laatste 3 dagen");
define("_NEWTHISWEEK","Nieuw deze week");
define("_CATNEWTODAY","Nieuwe links in deze categorie, vandaag toegevoegd");
define("_CATLAST3DAYS","Nieuwe links in deze categorie, in de laatste 3 dagen toegevoegd");
define("_CATTHISWEEK","Nieuwe links in deze categorie, deze week toegevoegd");
define("_POPULARITY1","Populariteit (minste hits bovenaan)");
define("_POPULARITY2","Populariteit (meeste hits bovenaan)");
define("_TITLEAZ","Titel (A t/m Z)");
define("_TITLEZA","Titel (Z t/m A)");
define("_DATE1","Date (Oudste link bovenaan)");
define("_DATE2","Date (Nieuwste link bovenaan)");
define("_RATING1","Rating (Laagste score bovenaan)");
define("_RATING2","Rating (Hoogste score bovenaan)");
define("_SEARCHRESULTS4","Zoek resultaten voor");
define("_USUBCATEGORIES","Subcategorien");
define("_LINKS","Links");
define("_TRY2SEARCH","Probeer te zoeken");
define("_INOTHERSENGINES","met zoekmachines van anderen");
define("_EDITORIAL","Redactieartikel");
define("_LINKPROFILE","Linkprofiel");
define("_EDITORIALBY","Redactieartikel door");
define("_NOEDITORIAL","Geen redactieartikel beschikbaar op dit moment voor deze website.");
define("_VISITTHISSITE","Bezoek deze website");
define("_RATETHISSITE","Waardeer deze website");
define("_ISTHISYOURSITE","Is dit uw bron?");
define("_ALLOWTORATE","Laat andere gebruikers uw website een waardering geven!");
define("_LINKRATINGDET","Linkwaardering details");
define("_OVERALLRATING","Algemene waardering");
define("_TOTALOF","Totaal van");
define("_USER","Gebruiker");
define("_USERAVGRATING","Gemiddelde waardering gebruikers");
define("_NUMRATINGS","Aantal waarderingen");
define("_EDITTHISLINK","Bewerk deze link");
define("_REGISTEREDUSERS","Geregistreerde gebruikers");
define("_NUMBEROFRATINGS","Aantal waarderingen");
define("_NOREGUSERSVOTES","Geen ledenstemmen");
define("_BREAKDOWNBYVAL","Waarderingsanalyse bij waarde");
define("_LTOTALVOTES","Totaal aantal stemmen");
define("_LINKRATING","Linkwaardering");
define("_HIGHRATING","Hoge waardering");
define("_LOWRATING","Lage waardering");
define("_NUMOFCOMMENTS","Aantal opmerkingen");
define("_WEIGHNOTE","* Noot: deze pagina vergelijkt niet-ledenwaarderingen met ledenwaarderingen");
define("_NOUNREGUSERSVOTES","Geen niet-ledenstemmen");
define("_WEIGHOUTNOTE","* Noot: deze pagina vergelijkt ledenstemmen met niet-ledenstemmen");
define("_NOOUTSIDEVOTES","Geen niet-ledenstemmen");
define("_OUTSIDEVOTERS","Niet-ledenstemmen");
define("_UNREGISTEREDUSERS","Niet-leden");
define("_PROMOTEYOURSITE","Promoot uw website");
define("_PROMOTE01","Bent u genteresseerd in een aantal van de Waardeer een website-opties die wij kunnen bieden? Met deze opties kunt u een afbeelding of een formulier op uw website plaatsen, om zo het aantal stemmen te verhogen. Kies uit de onderstaande opties:");
define("_TEXTLINK","Tekstlink");
define("_PROMOTE02","Een manier om te linken naar het waarderingsformulier is met een eenvoudige tekstlink:");
define("_HTMLCODE1","De HTML-code die u gebruikt in dit geval is als volgt:");
define("_THENUMBER","Het cijfer");
define("_IDREFER","in de HTML-broncode refereert naar het ID-nummer in de $sitename database. Zorg er dus voor dat dit nummer aanwezig is.");
define("_BUTTONLINK","Knop-link");
define("_PROMOTE03","Iets meer dan een gewonen tekstlink is de knop-link:");
define("_RATEIT","Stem op deze site!");
define("_HTMLCODE2","De broncode voor de bovenstaande knop is:");
define("_REMOTEFORM","Verwijder het waarderingsformulier");
define("_PROMOTE04","Het huidige waarderingsformulier ziet er zo uit.");
define("_VOTE4THISSITE","Stem op deze site!");
define("_LINKVOTE","Stem!");
define("_HTMLCODE3","Dit formulier laat gebruikers een waardering geven van uw website, rechtstreeks vanaf uw site. De waardering wordt dan hier verwerkt. Knip en plak de volgende broncode in uw webpagina, voor een formulier als het bovenstaande:");
define("_PROMOTE05","Bedankt, en veel succes met uw website!");
define("_STAFF","Staf");
define("_THANKSBROKEN","Bedankt voor uw hulp bij het up to date houden deze map.");
define("_THANKSFORINFO","Bedankt voor de informatie.");
define("_LOOKTOREQUEST","Wij zullen uw verzoek zo spoedig mogelijk in behandeling nemen.");
define("_REQUESTLINKMOD","Verzoek om linkwijziging");
define("_LINKID","Link ID");
define("_SENDREQUEST","Verzend verzoek");
define("_THANKSTOTAKETIME","Bedankt voor het waarderen van een site hier bij");
define("_LETSDECIDE","Inbreng van u helpt andere bezoekers om te beslissen welke links ze moeten bezoeken.");
define("_RETURNTO","Terug naar");
define("_RATENOTE1","U kunt maar een maal per dag op hetzelfde onderwerp stemmen.");
define("_RATENOTE2","De waardering loopt van 1 t/m 10, waarbij 1 staat voor zwak en 10 voor uitstekend.");
define("_RATENOTE3","Wees objectief bij het stemmen: als iedereen een 1 of een 10 geeft, dan zijn de waarderingen niet nuttig.");
define("_RATENOTE4","U kunt een lijst zien van de <a href=\"modules.php?name=Web_Links&amp;l_op=TopRated\">Hoogst gewaardeerde websites</a>.");
define("_RATENOTE5","Stem niet op uw eigen website of die van een concurrent.");
define("_YOUAREREGGED","U bent een geregistreerde gebruiker en u bent ingelogd.");
define("_FEELFREE2ADD","U bent van harte welkom om opmerkingen over deze site te plaatsen.");
define("_YOUARENOTREGGED","U bent geen geregistreerde gebruiker of U bent niet ingelogd.");
define("_IFYOUWEREREG","Alleen als u een geregistreerd gebruiker bent, kunt u opmerkingen plaatsen over deze website.");
define("_WEBLINKS","Weblinks");
define("_TITLE","Titel");
define("_MODIFY","Wijzig");
define("_COMPLETEVOTE1","Bedankt voor het uitbrengen van uw stem.");
define("_COMPLETEVOTE2","U heeft reeds gestemd: wacht nog a.u.b. $anonwaitdays dag(en).");
define("_COMPLETEVOTE3","U kunt hiervoor maar eenmaal stemmen<br>Alle stemmen worden opgeslagen en bekeken.");
define("_COMPLETEVOTE4","U kunt niet stemmen op een link die uzelf heeft aangemeld.<br>Alle stemmen worden opgeslagen en bekeken.");
define("_COMPLETEVOTE5","Geen waardering geselecteerd - er is geen stem bijgeteld");
define("_COMPLETEVOTE6","Er is slechts 1 stem per IP-addres toegestaan elke $outsidewaitdays dag(en).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Web_Links/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","Vorige pagina");
define("_NEXT","Volgende pagina");
define("_YOURNAME","Uw naam");
define("_CATEGORY","Categorie");
define("_CATEGORIES","Categorien");
define("_LVOTES","Stemmen");
define("_TOTALVOTES","Totaal aantal stemmen:");
define("_LINKTITLE","Linktitel");
define("_HITS","Hits:");
define("_THEREARE","Er zijn");
define("_NOMATCHES","Geen overeenkomsten gevonden");
define("_SCOMMENTS","Opmerkingen");
define("_DESCRIPTION","Beschrijving");
define("_ONLYREGUSERSMODIFY","Alleen leden kunnen suggesties doen m.b.t. downloadwijzigingen. A.u.b. <a href=\"modules.php?name=Your_Account\">registreren of inloggen</a>.");
define("_DATE","Datum");
define("_TO","Aan");
define("_ADDLINK","Link toevoegen");
define("_NEW","Nieuw");
define("_POPULAR","Populair");
define("_TOPRATED","Hoog(st) gewaardeerd");
define("_RANDOM","Willekeurig");
define("_LINKSMAIN","Hoofdlinks");
define("_LINKCOMMENTS","Link opmerkingen");
define("_ADDITIONALDET","Extra details");
define("_EDITORREVIEW","Auteurs recentie");
define("_REPORTBROKEN","Ongeldige link rapporteren");
define("_LINKSMAINCAT","Hoofdlinks categorien");
define("_AND","en");
define("_INDB","in onze database");
define("_ADDALINK","Nieuwe link toevoegen");
define("_INSTRUCTIONS","Instructies");
define("_SUBMITONCE","En link maar n keer inzenden.");
define("_POSTPENDING","Alle links worden geplaatst, in afwachting van goedkeuring.");
define("_USERANDIP","Gebruikersnaam en IP-adres worden geregistreerd, misbruik het systeem a.u.b. niet.");
define("_PAGETITLE","Paginatitel");
define("_PAGEURL","Pagina URL");
define("_YOUREMAIL","Uw e-mailadres");
define("_LDESCRIPTION","Beschrijving (max. 255 karakters):");
define("_ADDURL","Deze URL toevoegen");
define("_LINKSNOTUSER1","U bent geen geregistreerde gebruiker of U bent niet ingelogd.");
define("_LINKSNOTUSER2","Als U lid bent, kunt U links op deze website toevoegen.");
define("_LINKSNOTUSER3","Registreren duurt niet lang, en is niet moeilijk.");
define("_LINKSNOTUSER4","Waarom moet U zich registreren om toegang te krijgen tot bepaalde gedeeltes van deze site?");
define("_LINKSNOTUSER5","Alleen dan kunnen wij garant staan voor de inhoud van de inzendingen.");
define("_LINKSNOTUSER6","Elke inzending worden bekeken en daarna goed- of afgekeurd.");
define("_LINKSNOTUSER7","Wij streven ernaar u alleen nuttige informatie aan te bieden.");
define("_LINKSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Aanmelden voor een account</a>");
define("_LINKALREADYEXT","FOUT: Deze URL is reeds opgenomen in de database!");
define("_LINKNOTITLE","FOUT: U moet een TITEL opgeven voor uw URL!");
define("_LINKNOURL","FOUT: U moet een URL opgeven voor uw URL!");
define("_LINKNODESC","FOUT: U moet een BESCHRIJVING opgeven voor uw URL!");
define("_LINKRECEIVED","Wij hebben uw link-inzending ontvangen. Bedankt!");
define("_EMAILWHENADD","U zult een e-mail ontvangen als deze inzending goedgekeurd wordt.");
define("_CHECKFORIT","U heeft geen e-mailadres opgegeven. U zult daarom geen plaatsingsbericht ontvangen.");
define("_NEWLINKS","Nieuwe links");
define("_TOTALNEWLINKS","Totaal aantal nieuwe links");
define("_LASTWEEK","Laatste week");
define("_LAST30DAYS","Laatste 30 dagen");
define("_1WEEK","1 week");
define("_2WEEKS","2 weken");
define("_30DAYS","30 dagen");
define("_SHOW","Geef weer");
define("_TOTALFORLAST","Totaal aantal nieuwe links van de laatste");
define("_DAYS","dagen");
define("_ADDEDON","Toegevoegd op");
define("_RATING","Waardering");
define("_RATESITE","Waardering van deze site");
define("_DETAILS","Details");
define("_BESTRATED","Hoog gewaardeerde links - Top");
define("_OF","van");
define("_TRATEDLINKS","totaal aantal gewaardeerde links");
define("_TVOTESREQ","minimum aantal stemmen nodig");
define("_SHOWTOP","Geef Top weer");
define("_MOSTPOPULAR","Populairste links - Top");
define("_OFALL","van alle");
define("_SORTLINKSBY","Sorteer links op");
define("_SITESSORTED","Sites nu gesorteerd op");
define("_POPULARITY","Populariteit");
define("_SELECTPAGE","Selecteer pagina");
define("_MAIN","Hoofd");
define("_NEWTODAY","Nieuw vandaag");
define("_NEWLAST3DAYS","Nieuw laatste 3 dagen");
define("_NEWTHISWEEK","Nieuw deze week");
define("_CATNEWTODAY","Nieuwe links in deze categorie, vandaag toegevoegd");
define("_CATLAST3DAYS","Nieuwe links in deze categorie, in de laatste 3 dagen toegevoegd");
define("_CATTHISWEEK","Nieuwe links in deze categorie, deze week toegevoegd");
define("_POPULARITY1","Populariteit (minste hits bovenaan)");
define("_POPULARITY2","Populariteit (meeste hits bovenaan)");
define("_TITLEAZ","Titel (A t/m Z)");
define("_TITLEZA","Titel (Z t/m A)");
define("_DATE1","Date (Oudste link bovenaan)");
define("_DATE2","Date (Nieuwste link bovenaan)");
define("_RATING1","Rating (Laagste score bovenaan)");
define("_RATING2","Rating (Hoogste score bovenaan)");
define("_SEARCHRESULTS4","Zoek resultaten voor");
define("_USUBCATEGORIES","Subcategorien");
define("_LINKS","Links");
define("_TRY2SEARCH","Probeer te zoeken");
define("_INOTHERSENGINES","met zoekmachines van anderen");
define("_EDITORIAL","Redactieartikel");
define("_LINKPROFILE","Linkprofiel");
define("_EDITORIALBY","Redactieartikel door");
define("_NOEDITORIAL","Geen redactieartikel beschikbaar op dit moment voor deze website.");
define("_VISITTHISSITE","Bezoek deze website");
define("_RATETHISSITE","Waardeer deze website");
define("_ISTHISYOURSITE","Is dit uw bron?");
define("_ALLOWTORATE","Laat andere gebruikers uw website een waardering geven!");
define("_LINKRATINGDET","Linkwaardering details");
define("_OVERALLRATING","Algemene waardering");
define("_TOTALOF","Totaal van");
define("_USER","Gebruiker");
define("_USERAVGRATING","Gemiddelde waardering gebruikers");
define("_NUMRATINGS","Aantal waarderingen");
define("_EDITTHISLINK","Bewerk deze link");
define("_REGISTEREDUSERS","Geregistreerde gebruikers");
define("_NUMBEROFRATINGS","Aantal waarderingen");
define("_NOREGUSERSVOTES","Geen ledenstemmen");
define("_BREAKDOWNBYVAL","Waarderingsanalyse bij waarde");
define("_LTOTALVOTES","Totaal aantal stemmen");
define("_LINKRATING","Linkwaardering");
define("_HIGHRATING","Hoge waardering");
define("_LOWRATING","Lage waardering");
define("_NUMOFCOMMENTS","Aantal opmerkingen");
define("_WEIGHNOTE","* Noot: deze pagina vergelijkt niet-ledenwaarderingen met ledenwaarderingen");
define("_NOUNREGUSERSVOTES","Geen niet-ledenstemmen");
define("_WEIGHOUTNOTE","* Noot: deze pagina vergelijkt ledenstemmen met niet-ledenstemmen");
define("_NOOUTSIDEVOTES","Geen niet-ledenstemmen");
define("_OUTSIDEVOTERS","Niet-ledenstemmen");
define("_UNREGISTEREDUSERS","Niet-leden");
define("_PROMOTEYOURSITE","Promoot uw website");
define("_PROMOTE01","Bent u genteresseerd in een aantal van de Waardeer een website-opties die wij kunnen bieden? Met deze opties kunt u een afbeelding of een formulier op uw website plaatsen, om zo het aantal stemmen te verhogen. Kies uit de onderstaande opties:");
define("_TEXTLINK","Tekstlink");
define("_PROMOTE02","Een manier om te linken naar het waarderingsformulier is met een eenvoudige tekstlink:");
define("_HTMLCODE1","De HTML-code die u gebruikt in dit geval is als volgt:");
define("_THENUMBER","Het cijfer");
define("_IDREFER","in de HTML-broncode refereert naar het ID-nummer in de $sitename database. Zorg er dus voor dat dit nummer aanwezig is.");
define("_BUTTONLINK","Knop-link");
define("_PROMOTE03","Iets meer dan een gewonen tekstlink is de knop-link:");
define("_RATEIT","Stem op deze site!");
define("_HTMLCODE2","De broncode voor de bovenstaande knop is:");
define("_REMOTEFORM","Verwijder het waarderingsformulier");
define("_PROMOTE04","Het huidige waarderingsformulier ziet er zo uit.");
define("_VOTE4THISSITE","Stem op deze site!");
define("_LINKVOTE","Stem!");
define("_HTMLCODE3","Dit formulier laat gebruikers een waardering geven van uw website, rechtstreeks vanaf uw site. De waardering wordt dan hier verwerkt. Knip en plak de volgende broncode in uw webpagina, voor een formulier als het bovenstaande:");
define("_PROMOTE05","Bedankt, en veel succes met uw website!");
define("_STAFF","Staf");
define("_THANKSBROKEN","Bedankt voor uw hulp bij het up to date houden deze map.");
define("_THANKSFORINFO","Bedankt voor de informatie.");
define("_LOOKTOREQUEST","Wij zullen uw verzoek zo spoedig mogelijk in behandeling nemen.");
define("_REQUESTLINKMOD","Verzoek om linkwijziging");
define("_LINKID","Link ID");
define("_SENDREQUEST","Verzend verzoek");
define("_THANKSTOTAKETIME","Bedankt voor het waarderen van een site hier bij");
define("_LETSDECIDE","Inbreng van u helpt andere bezoekers om te beslissen welke links ze moeten bezoeken.");
define("_RETURNTO","Terug naar");
define("_RATENOTE1","U kunt maar een maal per dag op hetzelfde onderwerp stemmen.");
define("_RATENOTE2","De waardering loopt van 1 t/m 10, waarbij 1 staat voor zwak en 10 voor uitstekend.");
define("_RATENOTE3","Wees objectief bij het stemmen: als iedereen een 1 of een 10 geeft, dan zijn de waarderingen niet nuttig.");
define("_RATENOTE4","U kunt een lijst zien van de <a href=\"modules.php?name=Web_Links&amp;l_op=TopRated\">Hoogst gewaardeerde websites</a>.");
define("_RATENOTE5","Stem niet op uw eigen website of die van een concurrent.");
define("_YOUAREREGGED","U bent een geregistreerde gebruiker en u bent ingelogd.");
define("_FEELFREE2ADD","U bent van harte welkom om opmerkingen over deze site te plaatsen.");
define("_YOUARENOTREGGED","U bent geen geregistreerde gebruiker of U bent niet ingelogd.");
define("_IFYOUWEREREG","Alleen als u een geregistreerd gebruiker bent, kunt u opmerkingen plaatsen over deze website.");
define("_WEBLINKS","Weblinks");
define("_TITLE","Titel");
define("_MODIFY","Wijzig");
define("_COMPLETEVOTE1","Bedankt voor het uitbrengen van uw stem.");
define("_COMPLETEVOTE2","U heeft reeds gestemd: wacht nog a.u.b. $anonwaitdays dag(en).");
define("_COMPLETEVOTE3","U kunt hiervoor maar eenmaal stemmen<br>Alle stemmen worden opgeslagen en bekeken.");
define("_COMPLETEVOTE4","U kunt niet stemmen op een link die uzelf heeft aangemeld.<br>Alle stemmen worden opgeslagen en bekeken.");
define("_COMPLETEVOTE5","Geen waardering geselecteerd - er is geen stem bijgeteld");
define("_COMPLETEVOTE6","Er is slechts 1 stem per IP-addres toegestaan elke $outsidewaitdays dag(en).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>
